class Screen:
    """Sets the default argument values for
        --title
        --w
        --h
        """
    title = "FlashQuiz"
    width = 700
    height = 500
    dimensions = (width, height)
